@@ -1,22 +1,22 @@
 c\BeginDoc
 c
-c\Name: pznaup2 
+c\Name: pznaup2
 c
-c Message Passing Layer: MPI 
+c Message Passing Layer: MPI
 c
 c\Description: 
-c  Intermediate level interface called by pznaupd .
+c  Intermediate level interface called by pznaupd.
 c
 c\Usage:
-c  call pznaup2 
+c  call pznaup2
 c     ( COMM, IDO, BMAT, N, WHICH, NEV, NP, TOL, RESID, MODE, IUPD,
 c       ISHIFT, MXITER, V, LDV, H, LDH, RITZ, BOUNDS, 
 c       Q, LDQ, WORKL, IPNTR, WORKD, RWORK, INFO )
 c
 c\Arguments
 c
-c  COMM, IDO, BMAT, N, WHICH, NEV, TOL, RESID: same as defined in pznaupd .
-c  MODE, ISHIFT, MXITER: see the definition of IPARAM in pznaupd .
+c  COMM, IDO, BMAT, N, WHICH, NEV, TOL, RESID: same as defined in pznaupd.
+c  MODE, ISHIFT, MXITER: see the definition of IPARAM in pznaupd.
 c
 c  NP      Integer.  (INPUT/OUTPUT)
 c          Contains the number of implicit shifts to apply during
@@ -39,7 +39,7 @@ c  IUPD    Integer.  (INPUT)
 c          IUPD .EQ. 0: use explicit restart instead implicit update.
 c          IUPD .NE. 0: use implicit update.
 c
-c  V       Complex*16  N by (NEV+NP) array.  (INPUT/OUTPUT)
+c  V       Complex*16 N by (NEV+NP) array.  (INPUT/OUTPUT)
 c          The Arnoldi basis vectors are returned in the first NEV 
 c          columns of V.
 c
@@ -47,21 +47,21 @@ c  LDV     Integer.  (INPUT)
 c          Leading dimension of V exactly as declared in the calling 
 c          program.
 c
-c  H       Complex*16  (NEV+NP) by (NEV+NP) array.  (OUTPUT)
+c  H       Complex*16 (NEV+NP) by (NEV+NP) array.  (OUTPUT)
 c          H is used to store the generated upper Hessenberg matrix
 c
 c  LDH     Integer.  (INPUT)
 c          Leading dimension of H exactly as declared in the calling 
 c          program.
 c
-c  RITZ    Complex*16  array of length NEV+NP.  (OUTPUT)
+c  RITZ    Complex*16 array of length NEV+NP.  (OUTPUT)
 c          RITZ(1:NEV)  contains the computed Ritz values of OP.
 c
-c  BOUNDS  Complex*16  array of length NEV+NP.  (OUTPUT)
+c  BOUNDS  Complex*16 array of length NEV+NP.  (OUTPUT)
 c          BOUNDS(1:NEV) contain the error bounds corresponding to 
 c          the computed Ritz values.
 c          
-c  Q       Complex*16  (NEV+NP) by (NEV+NP) array.  (WORKSPACE)
+c  Q       Complex*16 (NEV+NP) by (NEV+NP) array.  (WORKSPACE)
 c          Private (replicated) work array used to accumulate the
 c          rotation in the shift application step.
 c
@@ -69,7 +69,7 @@ c  LDQ     Integer.  (INPUT)
 c          Leading dimension of Q exactly as declared in the calling
 c          program.
 c
-c  WORKL   Complex*16  work array of length at least 
+c  WORKL   Complex*16 work array of length at least 
 c          (NEV+NP)**2 + 3*(NEV+NP).  (WORKSPACE)
 c          Private (replicated) array on each PE or array allocated on
 c          the front end.  It is used in shifts calculation, shifts
@@ -86,13 +86,13 @@ c          IPNTR(3): pointer to the vector B * X when used in the
 c                    shift-and-invert mode.  X is the current operand.
 c          -------------------------------------------------------------
 c          
-c  WORKD   Complex*16  work array of length 3*N.  (WORKSPACE)
+c  WORKD   Complex*16 work array of length 3*N.  (WORKSPACE)
 c          Distributed array to be used in the basic Arnoldi iteration
 c          for reverse communication.  The user should not use WORKD
 c          as temporary workspace during the iteration !!!!!!!!!!
-c          See Data Distribution Note in PZNAUPD .
+c          See Data Distribution Note in PZNAUPD.
 c
-c  RWORK   Double precision    work array of length  NEV+NP ( WORKSPACE)
+c  RWORK   Double precision   work array of length  NEV+NP ( WORKSPACE)
 c          Private (replicated) array on each PE or array allocated on
 c          the front end.
 c
@@ -119,7 +119,7 @@ c
 c\BeginLib
 c
 c\Local variables:
-c     xxxxxx  Complex*16 
+c     xxxxxx  Complex*16
 c
 c\References:
 c  1. D.C. Sorensen, "Implicit Application of Polynomial Filters in
@@ -130,23 +130,23 @@ c     Restarted Arnoldi Iteration", Rice University Technical Report
 c     TR95-13, Department of Computational and Applied Mathematics.
 c
 c\Routines called:
-c     pzgetv0   Parallel ARPACK initial vector generation routine. 
-c     pznaitr   Parallel ARPACK Arnoldi factorization routine.
-c     pznapps   Parallel ARPACK application of implicit shifts routine.
-c     pzneigh   Parallel ARPACK compute Ritz values and error bounds routine. 
-c     pzngets   Parallel ARPACK reorder Ritz values and error bounds routine.
-c     zsortc    ARPACK sorting routine.
+c     pzgetv0  Parallel ARPACK initial vector generation routine. 
+c     pznaitr  Parallel ARPACK Arnoldi factorization routine.
+c     pznapps  Parallel ARPACK application of implicit shifts routine.
+c     pzneigh  Parallel ARPACK compute Ritz values and error bounds routine. 
+c     pzngets  Parallel ARPACK reorder Ritz values and error bounds routine.
+c     zsortc   ARPACK sorting routine.
 c     pivout   Parallel ARPACK utility routine that prints integers.
 c     second   ARPACK utility routine for timing.
-c     pzmout    Parallel ARPACK utility routine that prints matrices
-c     pzvout    Parallel ARPACK utility routine that prints vectors.
-c     pdvout    ARPACK utility routine that prints vectors.
-c     pdlamch   ScaLAPACK routine that determines machine constants.
-c     dlapy2    LAPACK routine to compute sqrt(x**2+y**2) carefully.
-c     zcopy     Level 1 BLAS that copies one vector to another .
-c     zdotc     Level 1 BLAS that computes the scalar product of two vectors. 
-c     zswap     Level 1 BLAS that swaps two vectors.
-c     pdznorm2  Parallel version of Level 1 BLAS that computes the norm of a vector.
+c     pzmout   Parallel ARPACK utility routine that prints matrices
+c     pzvout   Parallel ARPACK utility routine that prints vectors.
+c     pdvout   ARPACK utility routine that prints vectors.
+c     pdlamch  ScaLAPACK routine that determines machine constants.
+c     dlapy2   LAPACK routine to compute sqrt(x**2+y**2) carefully.
+c     zcopy    Level 1 BLAS that copies one vector to another .
+c     zdotc    Level 1 BLAS that computes the scalar product of two vectors. 
+c     zswap    Level 1 BLAS that swaps two vectors.
+c     pdznorm2 Parallel version of Level 1 BLAS that computes the norm of a vector.
 c
 c\Author
 c     Danny Sorensen               Phuong Vu
@@ -156,7 +156,7 @@ c     Applied Mathematics
 c     Rice University           
 c     Houston, Texas 
 c 
-c FILE: naup2.F   SID: 1.6   DATE OF SID: 06/01/00   RELEASE: 1
+c FILE: naup2.F   SID: 1.7   DATE OF SID: 10/25/03   RELEASE: 1
 c
 c\Remarks
 c     1. None
@@ -165,7 +165,7 @@ c\EndLib
 c
 c-----------------------------------------------------------------------
 c
-      subroutine pznaup2 
+      subroutine pznaup2
      &   ( comm, ido, bmat, n, which, nev, np, tol, resid, mode, iupd, 
      &     ishift, mxiter, v, ldv, h, ldh, ritz, bounds, 
      &     q, ldq, workl, ipntr, workd, rwork, info )
@@ -192,7 +192,7 @@ c
       character  bmat*1, which*2
       integer    ido, info, ishift, iupd, mode, ldh, ldq, ldv, mxiter,
      &           n, nev, np
-      Double precision   
+      Double precision  
      &           tol
 c
 c     %-----------------%
@@ -200,23 +200,23 @@ c     | Array Arguments |
 c     %-----------------%
 c
       integer    ipntr(13)
-      Complex*16 
+      Complex*16
      &           bounds(nev+np), h(ldh,nev+np), q(ldq,nev+np), 
      &           resid(n), ritz(nev+np),  v(ldv,nev+np), 
      &           workd(3*n), workl( (nev+np)*(nev+np+3) )
-       Double precision   
+       Double precision  
      &           rwork(nev+np)
 c
 c     %------------%
 c     | Parameters |
 c     %------------%
 c
-      Complex*16 
+      Complex*16
      &           one, zero
-      Double precision 
+      Double precision
      &           rzero
-      parameter (one = (1.0, 0.0) , zero = (0.0, 0.0) ,
-     &           rzero = 0.0 )
+      parameter (one = (1.0, 0.0), zero = (0.0, 0.0),
+     &           rzero = 0.0)
 c
 c     %---------------%
 c     | Local Scalars |
@@ -226,9 +226,9 @@ c
       integer    ierr ,  iter , kplusp, msglvl, nconv,
      &           nevbef, nev0 , np0   , nptemp, i    ,
      &           j
-      Complex*16 
+      Complex*16
      &           cmpnorm
-      Double precision 
+      Double precision
      &           rnorm,  eps23, rtemp
       character  wprime*2
 c
@@ -236,8 +236,7 @@ c
      &           rnorm,  iter , kplusp, msglvl, nconv, 
      &           nevbef, nev0 , np0,    eps23
 c
- 
-      Double precision 
+      Double precision
      &           cmpnorm_buf
 c
 c     %-----------------------%
@@ -250,25 +249,24 @@ c     %----------------------%
 c     | External Subroutines |
 c     %----------------------%
 c
-      external   zcopy , pzgetv0 , pznaitr , pzneigh , pzngets ,
-     &           pznapps , zsortc , zswap , pzmout , pzvout , pivout ,
-     &           second
+      external   zcopy, pzgetv0, pznaitr, pzneigh, pzngets, pznapps,
+     &           zsortc, zswap, pzmout, pzvout, pivout, second
 c
 c     %--------------------%
 c     | External functions |
 c     %--------------------%
 c
-      Complex*16 
-     &           zdotc 
-      Double precision   
-     &           pdznorm2 , pdlamch , dlapy2 
-      external   zdotc , pdznorm2 , pdlamch , dlapy2 
+      Complex*16
+     &           zdotc
+      Double precision  
+     &           pdznorm2, pdlamch, dlapy2
+      external   zdotc, pdznorm2, pdlamch, dlapy2
 c
 c     %---------------------%
 c     | Intrinsic Functions |
 c     %---------------------%
 c
-      intrinsic  dimag , dble , min, max, sqrt
+      intrinsic  dimag, dble, min, max, sqrt
 c
 c     %-----------------------%
 c     | Executable Statements |
@@ -300,8 +298,8 @@ c        %---------------------------------%
 c        | Get machine dependent constant. |
 c        %---------------------------------%
 c
-         eps23 = pdlamch (comm, 'Epsilon-Machine')
-         eps23 = eps23**(2.0  / 3.0 )
+         eps23 = pdlamch(comm, 'Epsilon-Machine')
+         eps23 = eps23**(2.0 / 3.0)
 c
 c        %---------------------------------------%
 c        | Set flags for computing the first NEV |
@@ -334,7 +332,7 @@ c
    10 continue
 c
       if (getv0) then
-         call pzgetv0  (comm, ido, bmat, 1, initv, n, 1, v, ldv, 
+         call pzgetv0 (comm, ido, bmat, 1, initv, n, 1, v, ldv, 
      &                 resid, rnorm, ipntr, workd, workl, info)
 c
          if (ido .ne. 99) go to 9000
@@ -376,7 +374,7 @@ c     %----------------------------------------------------------%
 c     | Compute the first NEV steps of the Arnoldi factorization |
 c     %----------------------------------------------------------%
 c
-      call pznaitr  (comm, ido, bmat, n, 0, nev, mode, 
+      call pznaitr (comm, ido, bmat, n, 0, nev, mode, 
      &             resid, rnorm, v, ldv, 
      &             h, ldh, ipntr, workd, workl, info)
 c
@@ -410,7 +408,7 @@ c
 c        %-----------------------------------------------------------%
 c        | Compute NP additional steps of the Arnoldi factorization. |
 c        | Adjust NP since NEV might have been updated by last call  |
-c        | to the shift application routine pznapps .                 |
+c        | to the shift application routine pznapps.                 |
 c        %-----------------------------------------------------------%
 c
          np  = kplusp - nev
@@ -430,7 +428,7 @@ c
    20    continue
          update = .true.
 c
-         call pznaitr  (comm, ido, bmat, n, nev, np, mode, 
+         call pznaitr (comm, ido, bmat, n, nev, np, mode, 
      &                resid, rnorm, v, ldv,
      &                h, ldh, ipntr, workd, workl, info)
 c
@@ -445,7 +443,7 @@ c
          update = .false.
 c
          if (msglvl .gt. 1) then
-            call pdvout  (comm, logfil, 1, rnorm, ndigit, 
+            call pdvout (comm, logfil, 1, rnorm, ndigit, 
      &           '_naup2: Corresponding B-norm of the residual')
          end if
 c 
@@ -454,7 +452,7 @@ c        | Compute the eigenvalues and corresponding error bounds |
 c        | of the current upper Hessenberg matrix.                |
 c        %--------------------------------------------------------%
 c
-         call pzneigh  ( comm, rnorm, kplusp, h, ldh, ritz, bounds,
+         call pzneigh ( comm, rnorm, kplusp, h, ldh, ritz, bounds,
      &                  q, ldq, workl, rwork,  ierr)
 c
          if (ierr .ne. 0) then
@@ -475,11 +473,11 @@ c
 c
 c        %--------------------------------------------------%
 c        | Make a copy of Ritz values and the corresponding |
-c        | Ritz estimates obtained from pzneigh .            |
+c        | Ritz estimates obtained from pzneigh.            |
 c        %--------------------------------------------------%
 c
-         call zcopy (kplusp,ritz,1,workl(kplusp**2+1),1)
-         call zcopy (kplusp,bounds,1,workl(kplusp**2+kplusp+1),1)
+         call zcopy(kplusp,ritz,1,workl(kplusp**2+1),1)
+         call zcopy(kplusp,bounds,1,workl(kplusp**2+kplusp+1),1)
 c
 c        %---------------------------------------------------%
 c        | Select the wanted Ritz values and their bounds    |
@@ -489,7 +487,7 @@ c        | bounds are in the last NEV loc. of RITZ           |
 c        | BOUNDS respectively.                              |
 c        %---------------------------------------------------%
 c
-         call pzngets  ( comm, ishift, which, nev, np, ritz, 
+         call pzngets ( comm, ishift, which, nev, np, ritz, 
      &                  bounds)
 c 
 c        %------------------------------------------------------------%
@@ -504,9 +502,9 @@ c
          nconv  = 0
 c
          do 25 i = 1, nev
-            rtemp = max( eps23, dlapy2 ( dble (ritz(np+i)),
-     &                                  dimag (ritz(np+i)) ) )
-            if ( dlapy2 (dble (bounds(np+i)),dimag (bounds(np+i)))
+            rtemp = max( eps23, dlapy2( dble(ritz(np+i)),
+     &                                  dimag(ritz(np+i)) ) )
+            if ( dlapy2(dble(bounds(np+i)),dimag(bounds(np+i)))
      &                 .le. tol*rtemp ) then
                nconv = nconv + 1
             end if
@@ -518,9 +516,9 @@ c
             kp(3) = nconv
             call pivout (comm, logfil, 3, kp, ndigit, 
      &                  '_naup2: NEV, NP, NCONV are')
-            call pzvout  (comm, logfil, kplusp, ritz, ndigit,
+            call pzvout (comm, logfil, kplusp, ritz, ndigit,
      &           '_naup2: The eigenvalues of H')
-            call pzvout  (comm, logfil, kplusp, bounds, ndigit, 
+            call pzvout (comm, logfil, kplusp, bounds, ndigit, 
      &          '_naup2: Ritz estimates of the current NCV Ritz values')
          end if
 c
@@ -547,10 +545,10 @@ c
      &        (np .eq. 0) ) then
 c
             if (msglvl .gt. 4) then
-               call pzvout (comm, logfil, kplusp, 
+               call pzvout(comm, logfil, kplusp, 
      &             workl(kplusp**2+1), ndigit,
      &             '_naup2: Eigenvalues computed by _neigh:')
-               call pzvout (comm, logfil, kplusp, 
+               call pzvout(comm, logfil, kplusp, 
      &             workl(kplusp**2+kplusp+1), ndigit,
      &             '_naup2: Ritz eistmates computed by _neigh:')
             end if
@@ -564,10 +562,10 @@ c           %------------------------------------------------%
 c
 c           %------------------------------------------%
 c           |  Use h( 3,1 ) as storage to communicate  |
-c           |  rnorm to pzneupd  if needed              |
+c           |  rnorm to pzneupd if needed              |
 c           %------------------------------------------%
 c
-            h(3,1) = dcmplx (rnorm,rzero)
+            h(3,1) = dcmplx(rnorm,rzero)
 c
 c           %----------------------------------------------%
 c           | Sort Ritz values so that converged Ritz      |
@@ -583,7 +581,7 @@ c
             if (which .eq. 'LI') wprime = 'SI'
             if (which .eq. 'SI') wprime = 'LI'
 c
-            call zsortc (wprime, .true., kplusp, ritz, bounds)
+            call zsortc(wprime, .true., kplusp, ritz, bounds)
 c
 c           %--------------------------------------------------%
 c           | Scale the Ritz estimate of each Ritz value       |
@@ -591,8 +589,8 @@ c           | by 1 / max(eps23, magnitude of the Ritz value).  |
 c           %--------------------------------------------------%
 c
             do 35 j = 1, nev0
-                rtemp = max( eps23, dlapy2 ( dble (ritz(j)),
-     &                                       dimag (ritz(j)) ) )
+                rtemp = max( eps23, dlapy2( dble(ritz(j)),
+     &                                       dimag(ritz(j)) ) )
                 bounds(j) = bounds(j)/rtemp
  35         continue
 c
@@ -604,7 +602,7 @@ c           | when NCONV < NEV.)                                |
 c           %---------------------------------------------------%
 c
             wprime = 'LM'
-            call zsortc (wprime, .true., nev0, bounds, ritz)
+            call zsortc(wprime, .true., nev0, bounds, ritz)
 c
 c           %----------------------------------------------%
 c           | Scale the Ritz estimate back to its original |
@@ -612,8 +610,8 @@ c           | value.                                       |
 c           %----------------------------------------------%
 c
             do 40 j = 1, nev0
-                rtemp = max( eps23, dlapy2 ( dble (ritz(j)),
-     &                                       dimag (ritz(j)) ) )
+                rtemp = max( eps23, dlapy2( dble(ritz(j)),
+     &                                       dimag(ritz(j)) ) )
                 bounds(j) = bounds(j)*rtemp
  40         continue
 c
@@ -623,12 +621,12 @@ c           | the "threshold" value appears at the front of |
 c           | ritz and bound.                               |
 c           %-----------------------------------------------%
 c
-            call zsortc (which, .true., nconv, ritz, bounds)
+            call zsortc(which, .true., nconv, ritz, bounds)
 c
             if (msglvl .gt. 1) then
-               call pzvout  (comm, logfil, kplusp, ritz, ndigit,
+               call pzvout (comm, logfil, kplusp, ritz, ndigit,
      &            '_naup2: Sorted eigenvalues')
-               call pzvout  (comm, logfil, kplusp, bounds, ndigit,
+               call pzvout (comm, logfil, kplusp, bounds, ndigit,
      &            '_naup2: Sorted ritz estimates.')
             end if
 c
@@ -670,7 +668,7 @@ c           | resort the eigenvalues.               |
 c           %---------------------------------------%
 c     
             if (nevbef .lt. nev) 
-     &         call pzngets  (comm, ishift, which, nev, np, ritz, 
+     &         call pzngets (comm, ishift, which, nev, np, ritz, 
      &                       bounds)
 c
          end if              
@@ -683,9 +681,9 @@ c
                kp(2) = np
                call pivout (comm, logfil, 2, kp, ndigit, 
      &              '_naup2: NEV and NP are')
-               call pzvout  (comm, logfil, nev, ritz(np+1), ndigit,
+               call pzvout (comm, logfil, nev, ritz(np+1), ndigit,
      &              '_naup2: "wanted" Ritz values ')
-               call pzvout  (comm, logfil, nev, bounds(np+1), ndigit,
+               call pzvout (comm, logfil, nev, bounds(np+1), ndigit,
      &              '_naup2: Ritz estimates of the "wanted" values ')
             end if
          end if
@@ -712,16 +710,16 @@ c            | RITZ, to free up WORKL           |
 c            | for non-exact shift case.        |
 c            %----------------------------------%
 c
-             call zcopy  (np, workl, 1, ritz, 1)
+             call zcopy (np, workl, 1, ritz, 1)
          end if
 c
          if (msglvl .gt. 2) then 
             call pivout (comm, logfil, 1, np, ndigit, 
      &                  '_naup2: The number of shifts to apply ')
-            call pzvout  (comm, logfil, np, ritz, ndigit,
+            call pzvout (comm, logfil, np, ritz, ndigit,
      &                  '_naup2: values of the shifts')
             if ( ishift .eq. 1 ) 
-     &          call pzvout  (comm, logfil, np, bounds, ndigit,
+     &          call pzvout (comm, logfil, np, bounds, ndigit,
      &                  '_naup2: Ritz estimates of the shifts')
          end if
 c
@@ -732,20 +730,20 @@ c        | matrix H.                                               |
 c        | The first 2*N locations of WORKD are used as workspace. |
 c        %---------------------------------------------------------%
 c
-         call pznapps (comm, n, nev, np, ritz, v, ldv, 
+         call pznapps(comm, n, nev, np, ritz, v, ldv, 
      &                h, ldh, resid, q, ldq, workl, workd)
 c
 c        %---------------------------------------------%
 c        | Compute the B-norm of the updated residual. |
 c        | Keep B*RESID in WORKD(1:N) to be used in    |
-c        | the first step of the next call to pznaitr . |
+c        | the first step of the next call to pznaitr. |
 c        %---------------------------------------------%
 c
          cnorm = .true.
          call second (t2)
          if (bmat .eq. 'G') then
             nbx = nbx + 1
-            call zcopy  (n, resid, 1, workd(n+1), 1)
+            call zcopy (n, resid, 1, workd(n+1), 1)
             ipntr(1) = n + 1
             ipntr(2) = 1
             ido = 2
@@ -756,7 +754,7 @@ c           %----------------------------------%
 c 
             go to 9000
          else if (bmat .eq. 'I') then
-            call zcopy  (n, resid, 1, workd, 1)
+            call zcopy (n, resid, 1, workd, 1)
          end if
 c 
   100    continue
@@ -772,19 +770,19 @@ c
          end if
 c 
          if (bmat .eq. 'G') then
-            cmpnorm_buf = zdotc  (n, resid, 1, workd, 1)
+            cmpnorm_buf = zdotc (n, resid, 1, workd, 1)
             call MPI_ALLREDUCE( cmpnorm_buf, cmpnorm, 1,
-     &               MPI_DOUBLE_COMPLEX , MPI_SUM, comm, ierr )
-            rnorm = sqrt(dlapy2 (dble (cmpnorm),dimag (cmpnorm)))
+     &               MPI_DOUBLE_COMPLEX, MPI_SUM, comm, ierr )
+            rnorm = sqrt(dlapy2(dble(cmpnorm),dimag(cmpnorm)))
          else if (bmat .eq. 'I') then
-            rnorm = pdznorm2 (comm, n, resid, 1)
+            rnorm = pdznorm2(comm, n, resid, 1)
          end if
          cnorm = .false.
 c
          if (msglvl .gt. 2) then
-            call pdvout  (comm, logfil, 1, rnorm, ndigit, 
+            call pdvout (comm, logfil, 1, rnorm, ndigit, 
      &      '_naup2: B-norm of residual for compressed factorization')
-            call pzmout  (comm, logfil, nev, nev, h, ldh, ndigit,
+            call pzmout (comm, logfil, nev, nev, h, ldh, ndigit,
      &        '_naup2: Compressed upper Hessenberg matrix H')
          end if
 c 
@@ -814,7 +812,7 @@ c
  9000 continue
 c
 c     %----------------%
-c     | End of pznaup2  |
+c     | End of pznaup2 |
 c     %----------------%
 c
       return
